"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createVueWebpackConfig = void 0;
const cli_1 = require("@leanjs/cli");
const webpack_1 = require("@leanjs/webpack");
const isEnvDevelopment = process.env.NODE_ENV === "development";
const isEnvProduction = process.env.NODE_ENV === "production";
const createVueWebpackConfig = () => {
    /* eslint-disable @typescript-eslint/no-var-requires */
    const { VueLoaderPlugin } = require("vue-loader");
    return {
        mode: isEnvDevelopment ? "development" : "production",
        plugins: [new VueLoaderPlugin(), new webpack_1.RemoteWebpackPlugin()],
        output: {
            filename: isEnvProduction ? "[name].[contenthash].js" : undefined,
            publicPath: "auto",
            path: (0, cli_1.getOutputPath)(),
        },
        module: {
            rules: [
                {
                    test: /\.vue$/,
                    use: "vue-loader",
                },
                {
                    test: /\.ts$/,
                    loader: "ts-loader",
                    options: {
                        configFile: `${process.cwd()}/tsconfig.json`,
                        appendTsSuffixTo: [/\.vue$/],
                    },
                },
                {
                    test: /\.m?js$/,
                    exclude: /node_modules/,
                    use: {
                        loader: "babel-loader",
                        options: {
                            presets: ["@babel/preset-env"],
                            plugins: ["@babel/plugin-transform-runtime"],
                        },
                    },
                },
            ],
        },
        resolve: {
            extensions: [".js", ".vue", ".ts"],
        },
    };
};
exports.createVueWebpackConfig = createVueWebpackConfig;
